/******************************************************************************
 *
 * System Name   : Rocinante Core Package
 * File Name     : ValidateUtilTest.js
 * Copyright     : (C) Copyright Rocinante Ein 2019
 *
 ******************************************************************************/

// テスト用ライブラリのロード
const test = require('ava');

// 精査用モジュールの読み込み
import validate from '../index.js';

/**
 * isNumber
 */
 test("====================isNumber Start====================", t => {
  t.is(true, true);
 });
test("isNumber関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber(null), false);
});
test("isNumber関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber(undefined), false);
});
test("isNumber関数に空文字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber(""), false);
});
test("isNumber関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("文字列"), false);
});
test("isNumber関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-01-01 00:00:00"), false);
});
test("isNumber関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-12-31 12:59:59"), false);
});
test("isNumber関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-00-01 00:00:00"), false);
});
test("isNumber関数にタイムスタンプ文字列（月が12より上）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-13-01 00:00:00"), false);
});
test("isNumber関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-01-32 00:00:00"), false);
});
test("isNumber関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-01-01 25:00:00"), false);
});
test("isNumber関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-01-01 00:60:00"), false);
});
test("isNumber関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-01-01 00:00:60"), false);
});
test("isNumber関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("2018-13-32 25:60:60"), false);
});
test("isNumber関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber("AAAA-01-01 00:00:00"), false);
});
test("isNumber関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber(true), false);
});
test("isNumber関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber(false), false);
});
test("isNumber関数に数字の0が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(0), true);
});
test("isNumber関数に数字の1が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(1), true);
});
test("isNumber関数に数字の-1が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(-1), true);
});
test("isNumber関数に数字の1.11が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(1.11), true);
});
test("isNumber関数に数字の-1.11が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(-1.11), true);
});
test("isNumber関数に整数の最大値が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.MAX_VALUE), true);
});
test("isNumber関数に整数の最大値+1が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.MAX_VALUE + 1), true);
});
test("isNumber関数に正の値の最小値が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.MIN_VALUE), true);
});
test("isNumber関数に整数の最小値-1が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.MIN_VALUE - 1), true);
});
test("isNumber関数に数字の最大値が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.POSITIVE_INFINITY), true);
});
test("isNumber関数に数字の最大値+1が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.POSITIVE_INFINITY + 1), true);
});
test("isNumber関数に数字の最小値が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.NEGATIVE_INFINITY), true);
});
test("isNumber関数に数字の最小値-1が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNumber(Number.NEGATIVE_INFINITY - 1), true);
});
test("isNumber関数に空の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNumber([]), false);
});
test("isNumber関数に配列が入ってきた場合、falseを返却する", t => {
   t.is(validate.isNumber(["配列","配列"]), false);
 });
 test("isNumber関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
   t.is(validate.isNumber({}), false);
 });
 test("isNumber関数にオブジェクトが入ってきた場合、falseを返却する", t => {
   t.is(validate.isNumber({"key":"オブジェクト"}), false);
 });
 test("isNumber関数に関数が入ってきた場合、falseを返却する", t => {
   const testUnitFunc = function(){
     console.log("test");
   };
   t.is(validate.isNumber(testUnitFunc), false);
 });
 test("isNumber関数にUUID文字列が入ってきた場合、falseを返却する", t => {
   t.is(validate.isNumber("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
 });
 test("====================isNumber End====================\n", t => {
  t.is(true, true);
 });


 /**
   * isNumbers
   */
 test("====================isNumbers Start====================", t => {
  t.is(true, true);
 });
 test("isNumbers関数にNULLが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers(null), false);
 });
 test("isNumbers関数に未定義値が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers(undefined), false);
 });
 test("isNumbers関数に文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers("文字列"), false);
 });
 test("isNumbers関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers({"key":"オブジェクト"}), false);
 });
 test("isNumbers関数に真偽値が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers(false), false);
 });
 test("isNumbers関数に数字が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers(0), false);
 });
 test("isNumbers関数に空の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([]), true);
 });
 test("isNumbers関数に関数が入ってきた場合、falseを返却する", t => {
   const testUnitFunc = function(){
     console.log("test");
   };
   t.is(validate.isNumbers(testUnitFunc), false);
 });
 test("isNumbers関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
   t.is(validate.isNumbers(new Date()), false);
 });


 test("isNumbers関数に-1.1〜1.1までの数字の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([-1.1,-1,1,0,1,1.1]), true);
 });
 test("isNumbers関数に-2〜2までの数字の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([-2,-1,0,1,2]), true);
 });
 test("isNumbers関数に-3〜-1までの数字の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([-3,-2,-1]), true);
 });
 test("isNumbers関数に-3〜0までの数字の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([-3,-2,-1,0]), true);
 });
 test("isNumbers関数に1〜3までの数字の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([1,2,3]), true);
 });
 test("isNumbers関数に0〜3までの数字の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isNumbers([0,1,2,3]), true);
 });
 test("isNumbers関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([true, false]), false);
 });
 test("isNumbers関数にtrueの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([true, true]), false);
 });
 test("isNumbers関数にfalseの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([false, false]), false);
 });
 test("isNumbers関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([function(){}, function(){}]), false);
 });
 test("isNumbers関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([undefined, undefined]), false);
 });
 test("isNumbers関数にnullの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([null, null]), false);
 });
 test("isNumbers関数にblankの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([undefined, null, "", false]), false);
 });
 test("isNumbers関数に文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers(["文字列","mojiretsu"]), false);
 });
 test("isNumbers関数に二次元配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([["配列","配列"],["配列","配列"]]), false);
 });
 test("isNumbers関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([{"key":"value"},{"key2":"値"}]), false);
 });
 test("isNumbers関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
   t.is(validate.isNumbers(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
 });
 test("isNumbers関数に日付の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNumbers([new Date(),new Date()]), false);
 });
 test("isNumbers関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
  t.is(validate.isNumbers([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
 });

 test("====================isNumbers End====================\n", t => {
  t.is(false, false);
 });

/**
  * isString
  */
test("====================isString Start====================", t => {
 t.is(true, true);
});
test("isString関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(null), false);
});
test("isString関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(undefined), false);
});
test("isString関数に空文字が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString(""), true);
});
test("isString関数に文字列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("文字列"), true);
});
test("isString関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-01-01 00:00:00"), true);
});
test("isString関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-12-31 12:59:59"), true);
});
test("isString関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-00-01 00:00:00"), true);
});
test("isString関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-13-01 00:00:00"), true);
});
test("isString関数にタイムスタンプ文字列（日が値外）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-01-32 00:00:00"), true);
});
test("isString関数にタイムスタンプ文字列（時が値外）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-01-01 25:00:00"), true);
});
test("isString関数にタイムスタンプ文字列（分が値外）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-01-01 00:60:00"), true);
});
test("isString関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-01-01 00:00:60"), true);
});
test("isString関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("2018-13-32 25:60:60"), true);
});
test("isString関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、trueを返却する", t => {
 t.is(validate.isString("AAAA-01-01 00:00:00"), true);
});
test("isString関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(true), false);
});
test("isString関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(false), false);
});
test("isString関数に数字の0が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(0), false);
});
test("isString関数に数字の1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(1), false);
});
test("isString関数に数字の-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(-1), false);
});
test("isString関数に数字の1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(1.11), false);
});
test("isString関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(-1.11), false);
});
test("isString関数に整数の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.MAX_VALUE), false);
});
test("isString関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.MAX_VALUE + 1), false);
});
test("isString関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.MIN_VALUE), false);
});
test("isString関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.MIN_VALUE - 1), false);
});
test("isString関数に数字の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.POSITIVE_INFINITY), false);
});
test("isString関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.POSITIVE_INFINITY + 1), false);
});
test("isString関数に数字の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.NEGATIVE_INFINITY), false);
});
test("isString関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(Number.NEGATIVE_INFINITY - 1), false);
});
test("isString関数に空の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString([]), false);
});
test("isString関数に配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isString(["配列","配列"]), false);
});
test("isString関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isString({}), false);
});
test("isString関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isString({"key":"オブジェクト"}), false);
});
test("isString関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isString(testUnitFunc), false);
});
test("isString関数にUUID文字列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isString("012345aB-0aAB-0aAB-0aAB-012345abcABC"), true);
});
test("====================isString End====================\n", t => {
 t.is(true, true);
});


/**
  * isStrings
  */
test("====================isStrings Start====================", t => {
 t.is(true, true);
});
test("isStrings関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings(null), false);
});
test("isStrings関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings(undefined), false);
});
test("isStrings関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings("文字列"), false);
});
test("isStrings関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings({"key":"オブジェクト"}), false);
});
test("isStrings関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings(false), false);
});
test("isStrings関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings(0), false);
});
test("isStrings関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isStrings([]), true);
});
test("isStrings関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isStrings(testUnitFunc), false);
});
test("isStrings関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isStrings(new Date()), false);
});


test("isStrings関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([-1.1,-1,1,0,1,1.1]),  false);
});
test("isStrings関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([-2,-1,0,1,2]), false);
});
test("isStrings関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([-3,-2,-1]), false);
});
test("isStrings関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([-3,-2,-1,0]), false);
});
test("isStrings関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([1,2,3]), false);
});
test("isStrings関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([0,1,2,3]), false);
});
test("isStrings関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([true, false]), false);
});
test("isStrings関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([true, true]), false);
});
test("isStrings関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([false, false]), false);
});
test("isStrings関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([function(){}, function(){}]), false);
});
test("isStrings関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([undefined, undefined]), false);
});
test("isStrings関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([null, null]), false);
});
test("isStrings関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([undefined, null, "", false]), false);
});
test("isStrings関数に文字列の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isStrings(["文字列","mojiretsu"]), true);
});
test("isStrings関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([["配列","配列"],["配列","配列"]]), false);
});
test("isStrings関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([{"key":"value"},{"key2":"値"}]), false);
});
test("isStrings関数にUUID文字列の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isStrings(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), true);
});
test("isStrings関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isStrings([new Date(),new Date()]), false);
});
test("isStrings関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isStrings([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isStrings End====================\n", t => {
 t.is(false, false);
});

/**
  * isArray
  */
test("====================isArray Start====================", t => {
 t.is(true, true);
});
test("isArray関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(null), false);
});
test("isArray関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(undefined), false);
});
test("isArray関数に空文字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(""), false);
});
test("isArray関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("文字列"), false);
});
test("isArray関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-01-01 00:00:00"), false);
});
test("isArray関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-12-31 12:59:59"), false);
});
test("isArray関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-00-01 00:00:00"), false);
});
test("isArray関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-13-01 00:00:00"), false);
});
test("isArray関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-01-32 00:00:00"), false);
});
test("isArray関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-01-01 25:00:00"), false);
});
test("isArray関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-01-01 00:60:00"), false);
});
test("isArray関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-01-01 00:00:60"), false);
});
test("isArray関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("2018-13-32 25:60:60"), false);
});
test("isArray関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray("AAAA-01-01 00:00:00"), false);
});
test("isArray関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(true), false);
});
test("isArray関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(false), false);
});
test("isArray関数に数字の0が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(0), false);
});
test("isArray関数に数字の1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(1), false);
});
test("isArray関数に数字の-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(-1), false);
});
test("isArray関数に数字の1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(1.11), false);
});
test("isArray関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(-1.11), false);
});
test("isArray関数に整数の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.MAX_VALUE), false);
});
test("isArray関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.MAX_VALUE + 1), false);
});
test("isArray関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.MIN_VALUE), false);
});
test("isArray関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.MIN_VALUE - 1), false);
});
test("isArray関数に数字の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.POSITIVE_INFINITY), false);
});
test("isArray関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.POSITIVE_INFINITY + 1), false);
});
test("isArray関数に数字の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.NEGATIVE_INFINITY), false);
});
test("isArray関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray(Number.NEGATIVE_INFINITY - 1), false);
});
test("isArray関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isArray([]), true);
});
test("isArray関数に配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isArray(["配列","配列"]), true);
});
test("isArray関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray({}), false);
});
test("isArray関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isArray({"key":"オブジェクト"}), false);
});
test("isArray関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isArray(testUnitFunc), false);
});
test("isArray関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isArray("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isArray End====================\n", t => {
 t.is(true, true);
});

/**
  * isArrays
  */
test("====================isArrays Start====================", t => {
 t.is(true, true);
});
test("isArrays関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays(null), false);
});
test("isArrays関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays(undefined), false);
});
test("isArrays関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays("文字列"), false);
});
test("isArrays関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays({"key":"オブジェクト"}), false);
});
test("isArrays関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays(false), false);
});
test("isArrays関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays(0), false);
});
test("isArrays関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isArrays([]), true);
});
test("isArrays関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isArrays(testUnitFunc), false);
});
test("isArrays関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isArrays(new Date()), false);
});


test("isArrays関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([-1.1,-1,1,0,1,1.1]),  false);
});
test("isArrays関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([-2,-1,0,1,2]), false);
});
test("isArrays関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([-3,-2,-1]), false);
});
test("isArrays関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([-3,-2,-1,0]), false);
});
test("isArrays関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([1,2,3]), false);
});
test("isArrays関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([0,1,2,3]), false);
});
test("isArrays関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([true, false]), false);
});
test("isArrays関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([true, true]), false);
});
test("isArrays関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([false, false]), false);
});
test("isArrays関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([function(){}, function(){}]), false);
});
test("isArrays関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([undefined, undefined]), false);
});
test("isArrays関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([null, null]), false);
});
test("isArrays関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([undefined, null, "", false]), false);
});
test("isArrays関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays(["文字列","mojiretsu"]), false);
});
test("isArrays関数に二次元配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isArrays([["配列","配列"],["配列","配列"]]), true);
});
test("isArrays関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([{"key":"value"},{"key2":"値"}]), false);
});
test("isArrays関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isArrays(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isArrays関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isArrays([new Date(),new Date()]), false);
});
test("isArrays関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isArrays([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isArrays End====================\n", t => {
 t.is(false, false);
});

/**
  * isObject
  */
test("====================isObject Start====================", t => {
 t.is(true, true);
});
test("isObject関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(null), false);
});
test("isObject関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(undefined), false);
});
test("isObject関数に空文字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(""), false);
});
test("isObject関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("文字列"), false);
});
test("isObject関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-01-01 00:00:00"), false);
});
test("isObject関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-12-31 12:59:59"), false);
});
test("isObject関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-00-01 00:00:00"), false);
});
test("isObject関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-13-01 00:00:00"), false);
});
test("isObject関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-01-32 00:00:00"), false);
});
test("isObject関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-01-01 25:00:00"), false);
});
test("isObject関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-01-01 00:60:00"), false);
});
test("isObject関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-01-01 00:00:60"), false);
});
test("isObject関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("2018-13-32 25:60:60"), false);
});
test("isObject関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject("AAAA-01-01 00:00:00"), false);
});
test("isObject関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(true), false);
});
test("isObject関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(false), false);
});
test("isObject関数に数字の0が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(0), false);
});
test("isObject関数に数字の1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(1), false);
});
test("isObject関数に数字の-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(-1), false);
});
test("isObject関数に数字の1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(1.11), false);
});
test("isObject関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(-1.11), false);
});
test("isObject関数に整数の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.MAX_VALUE), false);
});
test("isObject関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.MAX_VALUE + 1), false);
});
test("isObject関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.MIN_VALUE), false);
});
test("isObject関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.MIN_VALUE - 1), false);
});
test("isObject関数に数字の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.POSITIVE_INFINITY), false);
});
test("isObject関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.POSITIVE_INFINITY + 1), false);
});
test("isObject関数に数字の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.NEGATIVE_INFINITY), false);
});
test("isObject関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(Number.NEGATIVE_INFINITY - 1), false);
});
test("isObject関数に空の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject([]), false);
});
test("isObject関数に配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObject(["配列","配列"]), false);
});
test("isObject関数に空のオブジェクトが入ってきた場合、trueを返却する", t => {
 t.is(validate.isObject({}), true);
});
test("isObject関数にオブジェクトが入ってきた場合、trueを返却する", t => {
 t.is(validate.isObject({"key":"オブジェクト"}), true);
});
test("isObject関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isObject(testUnitFunc), false);
});
test("isObject関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isObject("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isObject End====================\n", t => {
 t.is(true, true);
});

/**
  * isObjects
  */
test("====================isObjects Start====================", t => {
 t.is(true, true);
});
test("isObjects関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects(null), false);
});
test("isObjects関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects(undefined), false);
});
test("isObjects関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects("文字列"), false);
});
test("isObjects関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects({"key":"オブジェクト"}), false);
});
test("isObjects関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects(false), false);
});
test("isObjects関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects(0), false);
});
test("isObjects関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isObjects([]), true);
});
test("isObjects関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isObjects(testUnitFunc), false);
});
test("isObjects関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isObjects(new Date()), false);
});


test("isObjects関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([-1.1,-1,1,0,1,1.1]),  false);
});
test("isObjects関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([-2,-1,0,1,2]), false);
});
test("isObjects関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([-3,-2,-1]), false);
});
test("isObjects関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([-3,-2,-1,0]), false);
});
test("isObjects関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([1,2,3]), false);
});
test("isObjects関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([0,1,2,3]), false);
});
test("isObjects関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([true, false]), false);
});
test("isObjects関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([true, true]), false);
});
test("isObjects関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([false, false]), false);
});
test("isObjects関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([function(){}, function(){}]), false);
});
test("isObjects関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([undefined, undefined]), false);
});
test("isObjects関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([null, null]), false);
});
test("isObjects関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([undefined, null, "", false]), false);
});
test("isObjects関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects(["文字列","mojiretsu"]), false);
});
test("isObjects関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([["配列","配列"],["配列","配列"]]), false);
});
test("isObjects関数にオブジェクトの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isObjects([{"key":"value"},{"key2":"値"}]), true);
});
test("isObjects関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isObjects(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isObjects関数に文字列の配列以外が入ってきた場合、falseを返却する", t => {
 t.is(validate.isObjects([new Date(),new Date()]), false);
});
test("isObjects関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isObjects([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isObjects End====================\n", t => {
 t.is(false, false);
});

/**
* isBoolean
*/

test("====================isBoolean Start====================", t => {
 t.is(true, true);
});
test("isBoolean関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(null), false);
});
test("isBoolean関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(undefined), false);
});
test("isBoolean関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(""), false);
});
test("isBoolean関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("文字列"), false);
});
test("isBoolean関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-01-01 00:00:00"), false);
});
test("isBoolean関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-12-31 12:59:59"), false);
});
test("isBoolean関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-00-01 00:00:00"), false);
});
test("isBoolean関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-13-01 00:00:00"), false);
});
test("isBoolean関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-01-32 00:00:00"), false);
});
test("isBoolean関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-01-01 25:00:00"), false);
});
test("isBoolean関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-01-01 00:60:00"), false);
});
test("isBoolean関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-01-01 00:00:60"), false);
});
test("isBoolean関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("2018-13-32 25:60:60"), false);
});
test("isBoolean関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean("AAAA-01-01 00:00:00"), false);
});
test("isBoolean関数に真偽値（TRUE）が入ってきた場合、trueを返却する", t => {
t.is(validate.isBoolean(true), true);
});
test("isBoolean関数に真偽値（FALSE）が入ってきた場合、trueを返却する", t => {
t.is(validate.isBoolean(false), true);
});
test("isBoolean関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(0), false);
});
test("isBoolean関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(1), false);
});
test("isBoolean関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(-1), false);
});
test("isBoolean関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(1.11), false);
});
test("isBoolean関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(-1.11), false);
});
test("isBoolean関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.MAX_VALUE), false);
});
test("isBoolean関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.MAX_VALUE + 1), false);
});
test("isBoolean関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.MIN_VALUE), false);
});
test("isBoolean関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.MIN_VALUE - 1), false);
});
test("isBoolean関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.POSITIVE_INFINITY), false);
});
test("isBoolean関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.POSITIVE_INFINITY + 1), false);
});
test("isBoolean関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.NEGATIVE_INFINITY), false);
});
test("isBoolean関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean(Number.NEGATIVE_INFINITY - 1), false);
});
test("isBoolean関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isBoolean([]), false);
});
test("isBoolean関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isBoolean(["配列","配列"]), false);
});
test("isBoolean関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isBoolean({}), false);
});
test("isBoolean関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isBoolean({"key":"オブジェクト"}), false);
});
test("isBoolean関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isBoolean(testUnitFunc), false);
});
test("isBoolean関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isBoolean("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isBoolean End====================\n", t => {
 t.is(true, true);
});

/**
  * isBooleans
  */
test("====================isBooleans Start====================", t => {
 t.is(true, true);
});
test("isBooleans関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans(null), false);
});
test("isBooleans関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans(undefined), false);
});
test("isBooleans関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans("文字列"), false);
});
test("isBooleans関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans({"key":"オブジェクト"}), false);
});
test("isBooleans関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans(false), false);
});
test("isBooleans関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans(0), false);
});
test("isBooleans関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBooleans([]), true);
});
test("isBooleans関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isBooleans(testUnitFunc), false);
});
test("isBooleans関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isBooleans(new Date()), false);
});


test("isBooleans関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([-1.1,-1,1,0,1,1.1]),  false);
});
test("isBooleans関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([-2,-1,0,1,2]), false);
});
test("isBooleans関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([-3,-2,-1]), false);
});
test("isBooleans関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([-3,-2,-1,0]), false);
});
test("isBooleans関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([1,2,3]), false);
});
test("isBooleans関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([0,1,2,3]), false);
});
test("isBooleans関数にtrue,falseの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBooleans([true, false]), true);
});
test("isBooleans関数にtrueの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBooleans([true, true]), true);
});
test("isBooleans関数にfalseの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBooleans([false, false]), true);
});
test("isBooleans関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([function(){}, function(){}]), false);
});
test("isBooleans関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([undefined, undefined]), false);
});
test("isBooleans関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([null, null]), false);
});
test("isBooleans関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([undefined, null, "", false]), false);
});
test("isBooleans関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans(["文字列","mojiretsu"]), false);
});
test("isBooleans関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([["配列","配列"],["配列","配列"]]), false);
});
test("isBooleans関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([{"key":"value"},{"key2":"値"}]), false);
});
test("isBooleans関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isBooleans(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isBooleans関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBooleans([new Date(),new Date()]), false);
});
test("isBooleans関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isBooleans([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isBooleans End====================\n", t => {
 t.is(false, false);
});

/**
* isFunction
*/

test("====================isFunction Start====================", t => {
 t.is(true, true);
});
test("isFunction関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(null), false);
});
test("isFunction関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(undefined), false);
});
test("isFunction関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(""), false);
});
test("isFunction関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("文字列"), false);
});
test("isFunction関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-01-01 00:00:00"), false);
});
test("isFunction関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-12-31 12:59:59"), false);
});
test("isFunction関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-00-01 00:00:00"), false);
});
test("isFunction関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-13-01 00:00:00"), false);
});
test("isFunction関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-01-32 00:00:00"), false);
});
test("isFunction関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-01-01 25:00:00"), false);
});
test("isFunction関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-01-01 00:60:00"), false);
});
test("isFunction関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-01-01 00:00:60"), false);
});
test("isFunction関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("2018-13-32 25:60:60"), false);
});
test("isFunction関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction("AAAA-01-01 00:00:00"), false);
});
test("isFunction関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(true), false);
});
test("isFunction関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(false), false);
});
test("isFunction関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(0), false);
});
test("isFunction関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(1), false);
});
test("isFunction関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(-1), false);
});
test("isFunction関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(1.11), false);
});
test("isFunction関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(-1.11), false);
});
test("isFunction関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.MAX_VALUE), false);
});
test("isFunction関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.MAX_VALUE + 1), false);
});
test("isFunction関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.MIN_VALUE), false);
});
test("isFunction関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.MIN_VALUE - 1), false);
});
test("isFunction関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.POSITIVE_INFINITY), false);
});
test("isFunction関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.POSITIVE_INFINITY + 1), false);
});
test("isFunction関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.NEGATIVE_INFINITY), false);
});
test("isFunction関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction(Number.NEGATIVE_INFINITY - 1), false);
});
test("isFunction関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isFunction([]), false);
});
test("isFunction関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isFunction(["配列","配列"]), false);
});
test("isFunction関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isFunction({}), false);
});
test("isFunction関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isFunction({"key":"オブジェクト"}), false);
});
test("isFunction関数に関数が入ってきた場合、trueを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isFunction(testUnitFunc), true);
});
test("isFunction関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isFunction("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isFunction End====================\n", t => {
 t.is(true, true);
});

/**
  * isFunctions
  */
test("====================isFunctions Start====================", t => {
 t.is(true, true);
});
test("isFunctions関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions(null), false);
});
test("isFunctions関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions(undefined), false);
});
test("isFunctions関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions("文字列"), false);
});
test("isFunctions関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions({"key":"オブジェクト"}), false);
});
test("isFunctions関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions(false), false);
});
test("isFunctions関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions(0), false);
});
test("isFunctions関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isFunctions([]), true);
});
test("isFunctions関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isFunctions(testUnitFunc), false);
});
test("isFunctions関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isFunctions(new Date()), false);
});


test("isFunctions関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([-1.1,-1,1,0,1,1.1]),  false);
});
test("isFunctions関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([-2,-1,0,1,2]), false);
});
test("isFunctions関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([-3,-2,-1]), false);
});
test("isFunctions関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([-3,-2,-1,0]), false);
});
test("isFunctions関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([1,2,3]), false);
});
test("isFunctions関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([0,1,2,3]), false);
});
test("isFunctions関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([true, false]), false);
});
test("isFunctions関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([true, true]), false);
});
test("isFunctions関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([false, false]), false);
});
test("isFunctions関数にfunctionの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isFunctions([function(){}, function(){}]), true);
});
test("isFunctions関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([undefined, undefined]), false);
});
test("isFunctions関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([null, null]), false);
});
test("isFunctions関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([undefined, null, "", false]), false);
});
test("isFunctions関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions(["文字列","mojiretsu"]), false);
});
test("isFunctions関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([["配列","配列"],["配列","配列"]]), false);
});
test("isFunctions関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([{"key":"value"},{"key2":"値"}]), false);
});
test("isFunctions関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isFunctions(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isFunctions関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFunctions([new Date(),new Date()]), false);
});
test("isFunctions関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isFunctions([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isFunctions End====================\n", t => {
 t.is(false, false);
});

/**
* isNull
*/

test("====================isNull Start====================", t => {
 t.is(false, false);
});
test("isNull関数にNULLが入ってきた場合、trueを返却する", t => {
t.is(validate.isNull(null), true);
});
test("isNull関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(undefined), false);
});
test("isNull関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(""), false);
});
test("isNull関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("文字列"), false);
});
test("isNull関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-01-01 00:00:00"), false);
});
test("isNull関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-12-31 12:59:59"), false);
});
test("isNull関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-00-01 00:00:00"), false);
});
test("isNull関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-13-01 00:00:00"), false);
});
test("isNull関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-01-32 00:00:00"), false);
});
test("isNull関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-01-01 25:00:00"), false);
});
test("isNull関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-01-01 00:60:00"), false);
});
test("isNull関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-01-01 00:00:60"), false);
});
test("isNull関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("2018-13-32 25:60:60"), false);
});
test("isNull関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull("AAAA-01-01 00:00:00"), false);
});
test("isNull関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(true), false);
});
test("isNull関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(false), false);
});
test("isNull関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(0), false);
});
test("isNull関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(1), false);
});
test("isNull関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(-1), false);
});
test("isNull関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(1.11), false);
});
test("isNull関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(-1.11), false);
});
test("isNull関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.MAX_VALUE), false);
});
test("isNull関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.MAX_VALUE + 1), false);
});
test("isNull関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.MIN_VALUE), false);
});
test("isNull関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.MIN_VALUE - 1), false);
});
test("isNull関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.POSITIVE_INFINITY), false);
});
test("isNull関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.POSITIVE_INFINITY + 1), false);
});
test("isNull関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.NEGATIVE_INFINITY), false);
});
test("isNull関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull(Number.NEGATIVE_INFINITY - 1), false);
});
test("isNull関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isNull([]), false);
});
test("isNull関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNull(["配列","配列"]), false);
});
test("isNull関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNull({}), false);
});
test("isNull関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNull({"key":"オブジェクト"}), false);
});
test("isNull関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isNull(testUnitFunc), false);
});
test("isNull関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNull("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isNull End====================\n", t => {
 t.is(false, false);
});

/**
  * isNulls
  */
test("====================isNulls Start====================", t => {
 t.is(true, true);
});
test("isNulls関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls(null), false);
});
test("isNulls関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls(undefined), false);
});
test("isNulls関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls("文字列"), false);
});
test("isNulls関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls({"key":"オブジェクト"}), false);
});
test("isNulls関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls(false), false);
});
test("isNulls関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls(0), false);
});
test("isNulls関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNulls([]), true);
});
test("isNulls関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isNulls(testUnitFunc), false);
});
test("isNulls関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNulls(new Date()), false);
});


test("isNulls関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([-1.1,-1,1,0,1,1.1]),  false);
});
test("isNulls関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([-2,-1,0,1,2]), false);
});
test("isNulls関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([-3,-2,-1]), false);
});
test("isNulls関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([-3,-2,-1,0]), false);
});
test("isNulls関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([1,2,3]), false);
});
test("isNulls関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([0,1,2,3]), false);
});
test("isNulls関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([true, false]), false);
});
test("isNulls関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([true, true]), false);
});
test("isNulls関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([false, false]), false);
});
test("isNulls関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([function(){}, function(){}]), false);
});
test("isNulls関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([undefined, undefined]), false);
});
test("isNulls関数にnullの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNulls([null, null]), true);
});
test("isNulls関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([undefined, null, "", false]), false);
});
test("isNulls関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls(["文字列","mojiretsu"]), false);
});
test("isNulls関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([["配列","配列"],["配列","配列"]]), false);
});
test("isNulls関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([{"key":"value"},{"key2":"値"}]), false);
});
test("isNulls関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNulls(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isNulls関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNulls([new Date(),new Date()]), false);
});
test("isNulls関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isNulls([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isNulls End====================\n", t => {
 t.is(false, false);
});

/**
* isUndefined
*/

test("====================isUndefined Start====================", t => {
 t.is(false, false);
});
test("isUndefined関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(null), false);
});
test("isUndefined関数に未定義値が入ってきた場合、trueを返却する", t => {
t.is(validate.isUndefined(undefined), true);
});
test("isUndefined関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(""), false);
});
test("isUndefined関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("文字列"), false);
});
test("isUndefined関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-01-01 00:00:00"), false);
});
test("isUndefined関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-12-31 12:59:59"), false);
});
test("isUndefined関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-00-01 00:00:00"), false);
});
test("isUndefined関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-13-01 00:00:00"), false);
});
test("isUndefined関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-01-32 00:00:00"), false);
});
test("isUndefined関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-01-01 25:00:00"), false);
});
test("isUndefined関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-01-01 00:60:00"), false);
});
test("isUndefined関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-01-01 00:00:60"), false);
});
test("isUndefined関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("2018-13-32 25:60:60"), false);
});
test("isUndefined関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined("AAAA-01-01 00:00:00"), false);
});
test("isUndefined関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(true), false);
});
test("isUndefined関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(false), false);
});
test("isUndefined関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(0), false);
});
test("isUndefined関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(1), false);
});
test("isUndefined関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(-1), false);
});
test("isUndefined関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(1.11), false);
});
test("isUndefined関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(-1.11), false);
});
test("isUndefined関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.MAX_VALUE), false);
});
test("isUndefined関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.MAX_VALUE + 1), false);
});
test("isUndefined関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.MIN_VALUE), false);
});
test("isUndefined関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.MIN_VALUE - 1), false);
});
test("isUndefined関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.POSITIVE_INFINITY), false);
});
test("isUndefined関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.POSITIVE_INFINITY + 1), false);
});
test("isUndefined関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.NEGATIVE_INFINITY), false);
});
test("isUndefined関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined(Number.NEGATIVE_INFINITY - 1), false);
});
test("isUndefined関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isUndefined([]), false);
});
test("isUndefined関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUndefined(["配列","配列"]), false);
});
test("isUndefined関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isUndefined({}), false);
});
test("isUndefined関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isUndefined({"key":"オブジェクト"}), false);
});
test("isUndefined関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isUndefined(testUnitFunc), false);
});
test("isUndefined関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUndefined("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isUndefined End====================\n", t => {
 t.is(false, false);
});

/**
  * isUndefineds
  */
test("====================isUndefineds Start====================", t => {
 t.is(true, true);
});
test("isUndefineds関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds(null), false);
});
test("isUndefineds関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds(undefined), false);
});
test("isUndefineds関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds("文字列"), false);
});
test("isUndefineds関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds({"key":"オブジェクト"}), false);
});
test("isUndefineds関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds(false), false);
});
test("isUndefineds関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds(0), false);
});
test("isUndefineds関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isUndefineds([]), true);
});
test("isUndefineds関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isUndefineds(testUnitFunc), false);
});
test("isUndefineds関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isUndefineds(new Date()), false);
});


test("isUndefineds関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([-1.1,-1,1,0,1,1.1]),  false);
});
test("isUndefineds関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([-2,-1,0,1,2]), false);
});
test("isUndefineds関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([-3,-2,-1]), false);
});
test("isUndefineds関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([-3,-2,-1,0]), false);
});
test("isUndefineds関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([1,2,3]), false);
});
test("isUndefineds関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([0,1,2,3]), false);
});
test("isUndefineds関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([true, false]), false);
});
test("isUndefineds関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([true, true]), false);
});
test("isUndefineds関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([false, false]), false);
});
test("isUndefineds関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([function(){}, function(){}]), false);
});
test("isUndefineds関数にundefinedの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isUndefineds([undefined, undefined]), true);
});
test("isUndefineds関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([null, null]), false);
});
test("isUndefineds関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([undefined, null, "", false]), false);
});
test("isUndefineds関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds(["文字列","mojiretsu"]), false);
});
test("isUndefineds関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([["配列","配列"],["配列","配列"]]), false);
});
test("isUndefineds関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([{"key":"value"},{"key2":"値"}]), false);
});
test("isUndefineds関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUndefineds(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isUndefineds関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUndefineds([new Date(),new Date()]), false);
});
test("isUndefineds関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isUndefineds([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isUndefineds End====================\n", t => {
 t.is(false, false);
});

/**
* isTrue
*/

test("====================isTrue Start====================", t => {
 t.is(false, false);
});
test("isTrue関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(null), false);
});
test("isTrue関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(undefined), false);
});
test("isTrue関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(""), false);
});
test("isTrue関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("文字列"), false);
});
test("isTrue関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-01-01 00:00:00"), false);
});
test("isTrue関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-12-31 12:59:59"), false);
});
test("isTrue関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-00-01 00:00:00"), false);
});
test("isTrue関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-13-01 00:00:00"), false);
});
test("isTrue関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-01-32 00:00:00"), false);
});
test("isTrue関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-01-01 25:00:00"), false);
});
test("isTrue関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-01-01 00:60:00"), false);
});
test("isTrue関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-01-01 00:00:60"), false);
});
test("isTrue関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("2018-13-32 25:60:60"), false);
});
test("isTrue関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue("AAAA-01-01 00:00:00"), false);
});
test("isTrue関数に真偽値（TRUE）が入ってきた場合、trueを返却する", t => {
t.is(validate.isTrue(true), true);
});
test("isTrue関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(false), false);
});
test("isTrue関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(0), false);
});
test("isTrue関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(1), false);
});
test("isTrue関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(-1), false);
});
test("isTrue関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(1.11), false);
});
test("isTrue関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(-1.11), false);
});
test("isTrue関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.MAX_VALUE), false);
});
test("isTrue関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.MAX_VALUE + 1), false);
});
test("isTrue関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.MIN_VALUE), false);
});
test("isTrue関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.MIN_VALUE - 1), false);
});
test("isTrue関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.POSITIVE_INFINITY), false);
});
test("isTrue関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.POSITIVE_INFINITY + 1), false);
});
test("isTrue関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.NEGATIVE_INFINITY), false);
});
test("isTrue関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue(Number.NEGATIVE_INFINITY - 1), false);
});
test("isTrue関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isTrue([]), false);
});
test("isTrue関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isTrue(["配列","配列"]), false);
});
test("isTrue関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isTrue({}), false);
});
test("isTrue関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isTrue({"key":"オブジェクト"}), false);
});
test("isTrue関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isTrue(testUnitFunc), false);
});
test("isTrue関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isTrue("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isTrue End====================\n", t => {
 t.is(false, false);
});

/**
  * isTrues
  */
test("====================isTrues Start====================", t => {
 t.is(true, true);
});
test("isTrues関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues(null), false);
});
test("isTrues関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues(undefined), false);
});
test("isTrues関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues("文字列"), false);
});
test("isTrues関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues({"key":"オブジェクト"}), false);
});
test("isTrues関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues(false), false);
});
test("isTrues関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues(0), false);
});
test("isTrues関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isTrues([]), true);
});
test("isTrues関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isTrues(testUnitFunc), false);
});
test("isTrues関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isTrues(new Date()), false);
});


test("isTrues関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([-1.1,-1,1,0,1,1.1]),  false);
});
test("isTrues関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([-2,-1,0,1,2]), false);
});
test("isTrues関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([-3,-2,-1]), false);
});
test("isTrues関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([-3,-2,-1,0]), false);
});
test("isTrues関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([1,2,3]), false);
});
test("isTrues関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([0,1,2,3]), false);
});
test("isTrues関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([true, false]), false);
});
test("isTrues関数にtrueの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isTrues([true, true]), true);
});
test("isTrues関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([false, false]), false);
});
test("isTrues関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([function(){}, function(){}]), false);
});
test("isTrues関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([undefined, undefined]), false);
});
test("isTrues関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([null, null]), false);
});
test("isTrues関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([undefined, null, "", false]), false);
});
test("isTrues関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues(["文字列","mojiretsu"]), false);
});
test("isTrues関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([["配列","配列"],["配列","配列"]]), false);
});
test("isTrues関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([{"key":"value"},{"key2":"値"}]), false);
});
test("isTrues関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isTrues(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isTrues関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isTrues([new Date(),new Date()]), false);
});
test("isTrues関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isTrues([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isTrues End====================\n", t => {
 t.is(false, false);
});

/**
* isFalse
*/

test("====================isFalse Start====================", t => {
 t.is(false, false);
});
test("isFalse関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(null), false);
});
test("isFalse関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(undefined), false);
});
test("isFalse関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(""), false);
});
test("isFalse関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("文字列"), false);
});
test("isFalse関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-01-01 00:00:00"), false);
});
test("isFalse関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-12-31 12:59:59"), false);
});
test("isFalse関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-00-01 00:00:00"), false);
});
test("isFalse関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-13-01 00:00:00"), false);
});
test("isFalse関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-01-32 00:00:00"), false);
});
test("isFalse関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-01-01 25:00:00"), false);
});
test("isFalse関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-01-01 00:60:00"), false);
});
test("isFalse関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-01-01 00:00:60"), false);
});
test("isFalse関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("2018-13-32 25:60:60"), false);
});
test("isFalse関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse("AAAA-01-01 00:00:00"), false);
});
test("isFalse関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(true), false);
});
test("isFalse関数に真偽値（FALSE）が入ってきた場合、trueを返却する", t => {
t.is(validate.isFalse(false), true);
});
test("isFalse関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(0), false);
});
test("isFalse関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(1), false);
});
test("isFalse関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(-1), false);
});
test("isFalse関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(1.11), false);
});
test("isFalse関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(-1.11), false);
});
test("isFalse関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.MAX_VALUE), false);
});
test("isFalse関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.MAX_VALUE + 1), false);
});
test("isFalse関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.MIN_VALUE), false);
});
test("isFalse関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.MIN_VALUE - 1), false);
});
test("isFalse関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.POSITIVE_INFINITY), false);
});
test("isFalse関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.POSITIVE_INFINITY + 1), false);
});
test("isFalse関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.NEGATIVE_INFINITY), false);
});
test("isFalse関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse(Number.NEGATIVE_INFINITY - 1), false);
});
test("isFalse関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isFalse([]), false);
});
test("isFalse関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isFalse(["配列","配列"]), false);
});
test("isFalse関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isFalse({}), false);
});
test("isFalse関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isFalse({"key":"オブジェクト"}), false);
});
test("isFalse関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isFalse(testUnitFunc), false);
});
test("isFalse関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isFalse("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isFalse End====================\n", t => {
 t.is(false, false);
});

/**
  * isFalses
  */
test("====================isFalses Start====================", t => {
 t.is(true, true);
});
test("isFalses関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses(null), false);
});
test("isFalses関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses(undefined), false);
});
test("isFalses関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses("文字列"), false);
});
test("isFalses関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses({"key":"オブジェクト"}), false);
});
test("isFalses関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses(false), false);
});
test("isFalses関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses(0), false);
});
test("isFalses関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isFalses([]), true);
});
test("isFalses関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isFalses(testUnitFunc), false);
});
test("isFalses関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isFalses(new Date()), false);
});


test("isFalses関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([-1.1,-1,1,0,1,1.1]),  false);
});
test("isFalses関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([-2,-1,0,1,2]), false);
});
test("isFalses関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([-3,-2,-1]), false);
});
test("isFalses関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([-3,-2,-1,0]), false);
});
test("isFalses関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([1,2,3]), false);
});
test("isFalses関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([0,1,2,3]), false);
});
test("isFalses関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([true, false]), false);
});
test("isFalses関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([true, true]), false);
});
test("isFalses関数にfalseの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isFalses([false, false]), true);
});
test("isFalses関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([function(){}, function(){}]), false);
});
test("isFalses関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([undefined, undefined]), false);
});
test("isFalses関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([null, null]), false);
});
test("isFalses関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([undefined, null, "", false]), false);
});
test("isFalses関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses(["文字列","mojiretsu"]), false);
});
test("isFalses関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([["配列","配列"],["配列","配列"]]), false);
});
test("isFalses関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([{"key":"value"},{"key2":"値"}]), false);
});
test("isFalses関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isFalses(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isFalses関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isFalses([new Date(),new Date()]), false);
});
test("isFalses関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isFalses([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isFalses End====================\n", t => {
 t.is(false, false);
});

/**
* isPositiveNumber
*/

test("====================isPositiveNumber Start====================", t => {
 t.is(false, false);
});
test("isPositiveNumber関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(null), false);
});
test("isPositiveNumber関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(undefined), false);
});
test("isPositiveNumber関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(""), false);
});
test("isPositiveNumber関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("文字列"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-01-01 00:00:00"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-12-31 12:59:59"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-00-01 00:00:00"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-13-01 00:00:00"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-01-32 00:00:00"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-01-01 25:00:00"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-01-01 00:60:00"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-01-01 00:00:60"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("2018-13-32 25:60:60"), false);
});
test("isPositiveNumber関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber("AAAA-01-01 00:00:00"), false);
});
test("isPositiveNumber関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(true), false);
});
test("isPositiveNumber関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(false), false);
});
test("isPositiveNumber関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(0), false);
});
test("isPositiveNumber関数に数字の1が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(1), true);
});
test("isPositiveNumber関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(-1), false);
});
test("isPositiveNumber関数に数字の1.11が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(1.11), true);
});
test("isPositiveNumber関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(-1.11), false);
});
test("isPositiveNumber関数に整数の最大値が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(Number.MAX_VALUE), true);
});
test("isPositiveNumber関数に整数の最大値+1が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(Number.MAX_VALUE + 1), true);
});
test("isPositiveNumber関数に正の値の最小値が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(Number.MIN_VALUE), true);
});
test("isPositiveNumber関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(Number.MIN_VALUE - 1), false);
});
test("isPositiveNumber関数に数字の最大値が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(Number.POSITIVE_INFINITY), true);
});
test("isPositiveNumber関数に数字の最大値+1が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveNumber(Number.POSITIVE_INFINITY + 1), true);
});
test("isPositiveNumber関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(Number.NEGATIVE_INFINITY), false);
});
test("isPositiveNumber関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber(Number.NEGATIVE_INFINITY - 1), false);
});
test("isPositiveNumber関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveNumber([]), false);
});
test("isPositiveNumber関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveNumber(["配列","配列"]), false);
});
test("isPositiveNumber関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveNumber({}), false);
});
test("isPositiveNumber関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveNumber({"key":"オブジェクト"}), false);
});
test("isPositiveNumber関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isPositiveNumber(testUnitFunc), false);
});
test("isPositiveNumber関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveNumber("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isPositiveNumber End====================\n", t => {
 t.is(false, false);
});


/**
  * isPositiveNumbers
  */
test("====================isPositiveNumbers Start====================", t => {
 t.is(true, true);
});
test("isPositiveNumbers関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers(null), false);
});
test("isPositiveNumbers関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers(undefined), false);
});
test("isPositiveNumbers関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers("文字列"), false);
});
test("isPositiveNumbers関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers({"key":"オブジェクト"}), false);
});
test("isPositiveNumbers関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers(false), false);
});
test("isPositiveNumbers関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers(0), false);
});
test("isPositiveNumbers関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isPositiveNumbers([]), true);
});
test("isPositiveNumbers関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isPositiveNumbers(testUnitFunc), false);
});
test("isPositiveNumbers関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveNumbers(new Date()), false);
});


test("isPositiveNumbers関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([-1.1,-1,1,0,1,1.1]),  false);
});
test("isPositiveNumbers関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([-2,-1,0,1,2]), false);
});
test("isPositiveNumbers関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([-3,-2,-1]), false);
});
test("isPositiveNumbers関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([-3,-2,-1,0]), false);
});
test("isPositiveNumbers関数に1〜3までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isPositiveNumbers([1,2,3]), true);
});
test("isPositiveNumbers関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([0,1,2,3]), false);
});
test("isPositiveNumbers関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([true, false]), false);
});
test("isPositiveNumbers関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([true, true]), false);
});
test("isPositiveNumbers関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([false, false]), false);
});
test("isPositiveNumbers関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([function(){}, function(){}]), false);
});
test("isPositiveNumbers関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([undefined, undefined]), false);
});
test("isPositiveNumbers関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([null, null]), false);
});
test("isPositiveNumbers関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([undefined, null, "", false]), false);
});
test("isPositiveNumbers関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers(["文字列","mojiretsu"]), false);
});
test("isPositiveNumbers関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([["配列","配列"],["配列","配列"]]), false);
});
test("isPositiveNumbers関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([{"key":"value"},{"key2":"値"}]), false);
});
test("isPositiveNumbers関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveNumbers(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isPositiveNumbers関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveNumbers([new Date(),new Date()]), false);
});
test("isPositiveNumbers関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isPositiveNumbers([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isPositiveNumbers End====================\n", t => {
 t.is(false, false);
});

/**
* isNegativeNumber
*/

test("====================isNegativeNumber Start====================", t => {
 t.is(false, false);
});
test("isNegativeNumber関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(null), false);
});
test("isNegativeNumber関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(undefined), false);
});
test("isNegativeNumber関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(""), false);
});
test("isNegativeNumber関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("文字列"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-01-01 00:00:00"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-12-31 12:59:59"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-00-01 00:00:00"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（月が値外1より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-13-01 00:00:00"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-01-32 00:00:00"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-01-01 25:00:00"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-01-01 00:60:00"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-01-01 00:00:60"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("2018-13-32 25:60:60"), false);
});
test("isNegativeNumber関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber("AAAA-01-01 00:00:00"), false);
});
test("isNegativeNumber関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(true), false);
});
test("isNegativeNumber関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(false), false);
});
test("isNegativeNumber関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(0), false);
});
test("isNegativeNumber関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(1), false);
});
test("isNegativeNumber関数に数字の-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeNumber(-1), true);
});
test("isNegativeNumber関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(1.11), false);
});
test("isNegativeNumber関数に数字の-1.11が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeNumber(-1.11), true);
});
test("isNegativeNumber関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(Number.MAX_VALUE), false);
});
test("isNegativeNumber関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(Number.MAX_VALUE + 1), false);
});
test("isNegativeNumber関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(Number.MIN_VALUE), false);
});
test("isNegativeNumber関数に整数の最小値-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeNumber(Number.MIN_VALUE - 1), true);
});
test("isNegativeNumber関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(Number.POSITIVE_INFINITY), false);
});
test("isNegativeNumber関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber(Number.POSITIVE_INFINITY + 1), false);
});
test("isNegativeNumber関数に数字の最小値が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeNumber(Number.NEGATIVE_INFINITY), true);
});
test("isNegativeNumber関数に数字の最小値-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeNumber(Number.NEGATIVE_INFINITY - 1), true);
});
test("isNegativeNumber関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeNumber([]), false);
});
test("isNegativeNumber関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeNumber(["配列","配列"]), false);
});
test("isNegativeNumber関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeNumber({}), false);
});
test("isNegativeNumber関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeNumber({"key":"オブジェクト"}), false);
});
test("isNegativeNumber関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isNegativeNumber(testUnitFunc), false);
});
test("isNegativeNumber関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeNumber("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isNegativeNumber End====================\n", t => {
 t.is(false, false);
});


/**
  * isNegativeNumbers
  */
test("====================isNegativeNumbers Start====================", t => {
 t.is(true, true);
});
test("isNegativeNumbers関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers(null), false);
});
test("isNegativeNumbers関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers(undefined), false);
});
test("isNegativeNumbers関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers("文字列"), false);
});
test("isNegativeNumbers関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers({"key":"オブジェクト"}), false);
});
test("isNegativeNumbers関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers(false), false);
});
test("isNegativeNumbers関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers(0), false);
});
test("isNegativeNumbers関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNegativeNumbers([]), true);
});
test("isNegativeNumbers関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isNegativeNumbers(testUnitFunc), false);
});
test("isNegativeNumbers関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeNumbers(new Date()), false);
});


test("isNegativeNumbers関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([-1.1,-1,1,0,1,1.1]),  false);
});
test("isNegativeNumbers関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([-2,-1,0,1,2]), false);
});
test("isNegativeNumbers関数に-3〜-1までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNegativeNumbers([-3,-2,-1]), true);
});
test("isNegativeNumbers関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([-3,-2,-1,0]), false);
});
test("isNegativeNumbers関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([1,2,3]), false);
});
test("isNegativeNumbers関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([0,1,2,3]), false);
});
test("isNegativeNumbers関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([true, false]), false);
});
test("isNegativeNumbers関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([true, true]), false);
});
test("isNegativeNumbers関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([false, false]), false);
});
test("isNegativeNumbers関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([function(){}, function(){}]), false);
});
test("isNegativeNumbers関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([undefined, undefined]), false);
});
test("isNegativeNumbers関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([null, null]), false);
});
test("isNegativeNumbers関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([undefined, null, "", false]), false);
});
test("isNegativeNumbers関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers(["文字列","mojiretsu"]), false);
});
test("isNegativeNumbers関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([["配列","配列"],["配列","配列"]]), false);
});
test("isNegativeNumbers関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([{"key":"value"},{"key2":"値"}]), false);
});
test("isNegativeNumbers関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeNumbers(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isNegativeNumbers関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeNumbers([new Date(),new Date()]), false);
});
test("isNegativeNumbers関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isNegativeNumbers([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isNegativeNumbers End====================\n", t => {
 t.is(false, false);
});


/**
* isInteger
*/

test("====================isInteger Start====================", t => {
 t.is(false, false);
});
test("isInteger関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(null), false);
});
test("isInteger関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(undefined), false);
});
test("isInteger関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(""), false);
});
test("isInteger関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("文字列"), false);
});
test("isInteger関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-01-01 00:00:00"), false);
});
test("isInteger関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-12-31 12:59:59"), false);
});
test("isInteger関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-00-01 00:00:00"), false);
});
test("isInteger関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-13-01 00:00:00"), false);
});
test("isInteger関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-01-32 00:00:00"), false);
});
test("isInteger関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-01-01 25:00:00"), false);
});
test("isInteger関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-01-01 00:60:00"), false);
});
test("isInteger関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-01-01 00:00:60"), false);
});
test("isInteger関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("2018-13-32 25:60:60"), false);
});
test("isInteger関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger("AAAA-01-01 00:00:00"), false);
});
test("isInteger関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(true), false);
});
test("isInteger関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(false), false);
});
test("isInteger関数に数字の0が入ってきた場合、trueを返却する", t => {
t.is(validate.isInteger(0), true);
});
test("isInteger関数に数字の1が入ってきた場合、trueを返却する", t => {
t.is(validate.isInteger(1), true);
});
test("isInteger関数に数字の-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isInteger(-1), true);
});
test("isInteger関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(1.11), false);
});
test("isInteger関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(-1.11), false);
});
test("isInteger関数に整数の最大値が入ってきた場合、trueを返却する", t => {
t.is(validate.isInteger(Number.MAX_VALUE), true);
});
test("isInteger関数に整数の最大値+1が入ってきた場合、trueを返却する", t => {
t.is(validate.isInteger(Number.MAX_VALUE + 1), true);
});
test("isInteger関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(Number.MIN_VALUE), false);
});
test("isInteger関数に整数の最小値-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isInteger(Number.MIN_VALUE - 1), true);
});
test("isInteger関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(Number.POSITIVE_INFINITY), false);
});
test("isInteger関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(Number.POSITIVE_INFINITY + 1), false);
});
test("isInteger関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(Number.NEGATIVE_INFINITY), false);
});
test("isInteger関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger(Number.NEGATIVE_INFINITY - 1), false);
});
test("isInteger関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isInteger([]), false);
});
test("isInteger関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isInteger(["配列","配列"]), false);
});
test("isInteger関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isInteger({}), false);
});
test("isInteger関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isInteger({"key":"オブジェクト"}), false);
});
test("isInteger関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isInteger(testUnitFunc), false);
});
test("isInteger関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isInteger("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isInteger End====================\n", t => {
 t.is(false, false);
});


/**
  * isIntegers
  */
test("====================isIntegers Start====================", t => {
 t.is(true, true);
});
test("isIntegers関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers(null), false);
});
test("isIntegers関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers(undefined), false);
});
test("isIntegers関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers("文字列"), false);
});
test("isIntegers関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers({"key":"オブジェクト"}), false);
});
test("isIntegers関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers(false), false);
});
test("isIntegers関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers(0), false);
});
test("isIntegers関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIntegers([]), true);
});
test("isIntegers関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isIntegers(testUnitFunc), false);
});
test("isIntegers関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isIntegers(new Date()), false);
});


test("isIntegers関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([-1.1,-1,1,0,1,1.1]),  false);
});
test("isIntegers関数に-2〜2までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIntegers([-2,-1,0,1,2]), true);
});
test("isIntegers関数に-3〜-1までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIntegers([-3,-2,-1]), true);
});
test("isIntegers関数に-3〜0までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIntegers([-3,-2,-1,0]), true);
});
test("isIntegers関数に1〜3までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIntegers([1,2,3]), true);
});
test("isIntegers関数に0〜3までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIntegers([0,1,2,3]), true);
});
test("isIntegers関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([true, false]), false);
});
test("isIntegers関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([true, true]), false);
});
test("isIntegers関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([false, false]), false);
});
test("isIntegers関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([function(){}, function(){}]), false);
});
test("isIntegers関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([undefined, undefined]), false);
});
test("isIntegers関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([null, null]), false);
});
test("isIntegers関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([undefined, null, "", false]), false);
});
test("isIntegers関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers(["文字列","mojiretsu"]), false);
});
test("isIntegers関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([["配列","配列"],["配列","配列"]]), false);
});
test("isIntegers関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([{"key":"value"},{"key2":"値"}]), false);
});
test("isIntegers関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isIntegers(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isIntegers関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIntegers([new Date(),new Date()]), false);
});
test("isIntegers関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isIntegers([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isIntegers End====================\n", t => {
 t.is(false, false);
});

/**
* isPositiveInteger
*/

test("====================isPositiveInteger Start====================", t => {
 t.is(false, false);
});
test("isPositiveInteger関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(null), false);
});
test("isPositiveInteger関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(undefined), false);
});
test("isPositiveInteger関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(""), false);
});
test("isPositiveInteger関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("文字列"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-01-01 00:00:00"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-12-31 12:59:59"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-00-01 00:00:00"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-13-01 00:00:00"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-01-32 00:00:00"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-01-01 25:00:00"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-01-01 00:60:00"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-01-01 00:00:60"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("2018-13-32 25:60:60"), false);
});
test("isPositiveInteger関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger("AAAA-01-01 00:00:00"), false);
});
test("isPositiveInteger関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(true), false);
});
test("isPositiveInteger関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(false), false);
});
test("isPositiveInteger関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(0), false);
});
test("isPositiveInteger関数に数字の1が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveInteger(1), true);
});
test("isPositiveInteger関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(-1), false);
});
test("isPositiveInteger関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(1.11), false);
});
test("isPositiveInteger関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(-1.11), false);
});
test("isPositiveInteger関数に整数の最大値が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveInteger(Number.MAX_VALUE), true);
});
test("isPositiveInteger関数に整数の最大値+1が入ってきた場合、trueを返却する", t => {
t.is(validate.isPositiveInteger(Number.MAX_VALUE + 1), true);
});
test("isPositiveInteger関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(Number.MIN_VALUE), false);
});
test("isPositiveInteger関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(Number.MIN_VALUE - 1), false);
});
test("isPositiveInteger関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(Number.POSITIVE_INFINITY), false);
});
test("isPositiveInteger関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(Number.POSITIVE_INFINITY + 1), false);
});
test("isPositiveInteger関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(Number.NEGATIVE_INFINITY), false);
});
test("isPositiveInteger関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger(Number.NEGATIVE_INFINITY - 1), false);
});
test("isPositiveInteger関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isPositiveInteger([]), false);
});
test("isPositiveInteger関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveInteger(["配列","配列"]), false);
});
test("isPositiveInteger関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveInteger({}), false);
});
test("isPositiveInteger関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveInteger({"key":"オブジェクト"}), false);
});
test("isPositiveInteger関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isPositiveInteger(testUnitFunc), false);
});
test("isPositiveInteger関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveInteger("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isPositiveInteger End====================\n", t => {
 t.is(false, false);
});

/**
  * isPositiveIntegers
  */
test("====================isPositiveIntegers Start====================", t => {
 t.is(true, true);
});
test("isPositiveIntegers関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers(null), false);
});
test("isPositiveIntegers関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers(undefined), false);
});
test("isPositiveIntegers関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers("文字列"), false);
});
test("isPositiveIntegers関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers({"key":"オブジェクト"}), false);
});
test("isPositiveIntegers関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers(false), false);
});
test("isPositiveIntegers関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers(0), false);
});
test("isPositiveIntegers関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isPositiveIntegers([]), true);
});
test("isPositiveIntegers関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isPositiveIntegers(testUnitFunc), false);
});
test("isPositiveIntegers関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveIntegers(new Date()), false);
});


test("isPositiveIntegers関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([-1.1,-1,1,0,1,1.1]),  false);
});
test("isPositiveIntegers関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([-2,-1,0,1,2]), false);
});
test("isPositiveIntegers関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([-3,-2,-1]), false);
});
test("isPositiveIntegers関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([-3,-2,-1,0]), false);
});
test("isPositiveIntegers関数に1〜3までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isPositiveIntegers([1,2,3]), true);
});
test("isPositiveIntegers関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([0,1,2,3]), false);
});
test("isPositiveIntegers関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([true, false]), false);
});
test("isPositiveIntegers関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([true, true]), false);
});
test("isPositiveIntegers関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([false, false]), false);
});
test("isPositiveIntegers関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([function(){}, function(){}]), false);
});
test("isPositiveIntegers関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([undefined, undefined]), false);
});
test("isPositiveIntegers関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([null, null]), false);
});
test("isPositiveIntegers関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([undefined, null, "", false]), false);
});
test("isPositiveIntegers関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers(["文字列","mojiretsu"]), false);
});
test("isPositiveIntegers関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([["配列","配列"],["配列","配列"]]), false);
});
test("isPositiveIntegers関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([{"key":"value"},{"key2":"値"}]), false);
});
test("isPositiveIntegers関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isPositiveIntegers(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isPositiveIntegers関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isPositiveIntegers([new Date(),new Date()]), false);
});
test("isPositiveIntegers関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isPositiveIntegers([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isPositiveIntegers End====================\n", t => {
 t.is(false, false);
});

/**
* isNegativeInteger
*/

test("====================isNegativeInteger Start====================", t => {
 t.is(false, false);
});
test("isNegativeInteger関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(null), false);
});
test("isNegativeInteger関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(undefined), false);
});
test("isNegativeInteger関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(""), false);
});
test("isNegativeInteger関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("文字列"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-01-01 00:00:00"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-12-31 12:59:59"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-00-01 00:00:00"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-13-01 00:00:00"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-01-32 00:00:00"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-01-01 25:00:00"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-01-01 00:60:00"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-01-01 00:00:60"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("2018-13-32 25:60:60"), false);
});
test("isNegativeInteger関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger("AAAA-01-01 00:00:00"), false);
});
test("isNegativeInteger関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(true), false);
});
test("isNegativeInteger関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(false), false);
});
test("isNegativeInteger関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(0), false);
});
test("isNegativeInteger関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(1), false);
});
test("isNegativeInteger関数に数字の-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeInteger(-1), true);
});
test("isNegativeInteger関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(1.11), false);
});
test("isNegativeInteger関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(-1.11), false);
});
test("isNegativeInteger関数に整数の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.MAX_VALUE), false);
});
test("isNegativeInteger関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.MAX_VALUE + 1), false);
});
test("isNegativeInteger関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.MIN_VALUE), false);
});
test("isNegativeInteger関数に整数の最小値-1が入ってきた場合、trueを返却する", t => {
t.is(validate.isNegativeInteger(Number.MIN_VALUE - 1), true);
});
test("isNegativeInteger関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.POSITIVE_INFINITY), false);
});
test("isNegativeInteger関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.POSITIVE_INFINITY + 1), false);
});
test("isNegativeInteger関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.NEGATIVE_INFINITY), false);
});
test("isNegativeInteger関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger(Number.NEGATIVE_INFINITY - 1), false);
});
test("isNegativeInteger関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isNegativeInteger([]), false);
});
test("isNegativeInteger関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeInteger(["配列","配列"]), false);
});
test("isNegativeInteger関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeInteger({}), false);
});
test("isNegativeInteger関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeInteger({"key":"オブジェクト"}), false);
});
test("isNegativeInteger関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isNegativeInteger(testUnitFunc), false);
});
test("isNegativeInteger関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeInteger("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isNegativeInteger End====================\n", t => {
 t.is(false, false);
});


/**
  * isNegativeIntegers
  */
test("====================isNegativeIntegers Start====================", t => {
 t.is(true, true);
});
test("isNegativeIntegers関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers(null), false);
});
test("isNegativeIntegers関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers(undefined), false);
});
test("isNegativeIntegers関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers("文字列"), false);
});
test("isNegativeIntegers関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers({"key":"オブジェクト"}), false);
});
test("isNegativeIntegers関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers(false), false);
});
test("isNegativeIntegers関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers(0), false);
});
test("isNegativeIntegers関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNegativeIntegers([]), true);
});
test("isNegativeIntegers関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isNegativeIntegers(testUnitFunc), false);
});
test("isNegativeIntegers関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeIntegers(new Date()), false);
});


test("isNegativeIntegers関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([-1.1,-1,1,0,1,1.1]),  false);
});
test("isNegativeIntegers関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([-2,-1,0,1,2]), false);
});
test("isNegativeIntegers関数に-3〜-1までの数字の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isNegativeIntegers([-3,-2,-1]), true);
});
test("isNegativeIntegers関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([-3,-2,-1,0]), false);
});
test("isNegativeIntegers関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([1,2,3]), false);
});
test("isNegativeIntegers関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([0,1,2,3]), false);
});
test("isNegativeIntegers関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([true, false]), false);
});
test("isNegativeIntegers関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([true, true]), false);
});
test("isNegativeIntegers関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([false, false]), false);
});
test("isNegativeIntegers関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([function(){}, function(){}]), false);
});
test("isNegativeIntegers関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([undefined, undefined]), false);
});
test("isNegativeIntegers関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([null, null]), false);
});
test("isNegativeIntegers関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([undefined, null, "", false]), false);
});
test("isNegativeIntegers関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers(["文字列","mojiretsu"]), false);
});
test("isNegativeIntegers関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([["配列","配列"],["配列","配列"]]), false);
});
test("isNegativeIntegers関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([{"key":"value"},{"key2":"値"}]), false);
});
test("isNegativeIntegers関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isNegativeIntegers(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isNegativeIntegers関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isNegativeIntegers([new Date(),new Date()]), false);
});
test("isNegativeIntegers関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isNegativeIntegers([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isNegativeIntegers End====================\n", t => {
 t.is(false, false);
});

/**
 * isUuid
 */
 test("====================isUuid Start====================", t => {
  t.is(false, false);
 });
test("isUuid関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(null), false);
});
test("isUuid関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(undefined), false);
});
test("isUuid関数に空文字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(""), false);
});
test("isUuid関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("文字列"), false);
});
test("isUuid関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-01-01 00:00:00"), false);
});
test("isUuid関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-12-31 12:59:59"), false);
});
test("isUuid関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-00-01 00:00:00"), false);
});
test("isUuid関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-13-01 00:00:00"), false);
});
test("isUuid関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-01-32 00:00:00"), false);
});
test("isUuid関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-01-01 25:00:00"), false);
});
test("isUuid関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-01-01 00:60:00"), false);
});
test("isUuid関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-01-01 00:00:60"), false);
});
test("isUuid関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("2018-13-32 25:60:60"), false);
});
test("isUuid関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid("AAAA-01-01 00:00:00"), false);
});
test("isUuid関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(true), false);
});
test("isUuid関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(false), false);
});
test("isUuid関数に数字の0が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(0), false);
});
test("isUuid関数に数字の1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(1), false);
});
test("isUuid関数に数字の-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(-1), false);
});
test("isUuid関数に数字の1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(1.11), false);
});
test("isUuid関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(-1.11), false);
});
test("isUuid関数に整数の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.MAX_VALUE), false);
});
test("isUuid関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.MAX_VALUE + 1), false);
});
test("isUuid関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.MIN_VALUE), false);
});
test("isUuid関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.MIN_VALUE - 1), false);
});
test("isUuid関数に数字の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.POSITIVE_INFINITY), false);
});
test("isUuid関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.POSITIVE_INFINITY + 1), false);
});
test("isUuid関数に数字の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.NEGATIVE_INFINITY), false);
});
test("isUuid関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid(Number.NEGATIVE_INFINITY - 1), false);
});
test("isUuid関数に空の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isUuid([]), false);
});
test("isUuid関数に配列が入ってきた場合、falseを返却する", t => {
   t.is(validate.isUuid(["配列","配列"]), false);
 });
 test("isUuid関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
   t.is(validate.isUuid({}), false);
 });
 test("isUuid関数にオブジェクトが入ってきた場合、falseを返却する", t => {
   t.is(validate.isUuid({"key":"オブジェクト"}), false);
 });
 test("isUuid関数に関数が入ってきた場合、falseを返却する", t => {
   const testUnitFunc = function(){
     console.log("test");
   };
   t.is(validate.isUuid(testUnitFunc), false);
 });
 test("isUuid関数にUUID文字列が入ってきた場合、trueを返却する", t => {
   t.is(validate.isUuid("012345aB-0aAB-0aAB-0aAB-012345abcABC"), true);
 });
 test("====================isUuid End====================\n", t => {
  t.is(false, false);
 });


 /**
   * isUuids
   */
 test("====================isUuids Start====================", t => {
  t.is(true, true);
 });
 test("isUuids関数にNULLが入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids(null), false);
 });
 test("isUuids関数に未定義値が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids(undefined), false);
 });
 test("isUuids関数に文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids("文字列"), false);
 });
 test("isUuids関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids({"key":"オブジェクト"}), false);
 });
 test("isUuids関数に真偽値が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids(false), false);
 });
 test("isUuids関数に数字が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids(0), false);
 });
 test("isUuids関数に空の配列が入ってきた場合、trueを返却する", t => {
  t.is(validate.isUuids([]), true);
 });
 test("isUuids関数に関数が入ってきた場合、falseを返却する", t => {
   const testUnitFunc = function(){
     console.log("test");
   };
   t.is(validate.isUuids(testUnitFunc), false);
 });
 test("isUuids関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
   t.is(validate.isUuids(new Date()), false);
 });


 test("isUuids関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([-1.1,-1,1,0,1,1.1]),  false);
 });
 test("isUuids関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([-2,-1,0,1,2]), false);
 });
 test("isUuids関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([-3,-2,-1]), false);
 });
 test("isUuids関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([-3,-2,-1,0]), false);
 });
 test("isUuids関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([1,2,3]), false);
 });
 test("isUuids関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([0,1,2,3]), false);
 });
 test("isUuids関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([true, false]), false);
 });
 test("isUuids関数にtrueの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([true, true]), false);
 });
 test("isUuids関数にfalseの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([false, false]), false);
 });
 test("isUuids関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([function(){}, function(){}]), false);
 });
 test("isUuids関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([undefined, undefined]), false);
 });
 test("isUuids関数にnullの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([null, null]), false);
 });
 test("isUuids関数にblankの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([undefined, null, "", false]), false);
 });
 test("isUuids関数に文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids(["文字列","mojiretsu"]), false);
 });
 test("isUuids関数に二次元配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([["配列","配列"],["配列","配列"]]), false);
 });
 test("isUuids関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([{"key":"value"},{"key2":"値"}]), false);
 });
 test("isUuids関数にUUID文字列の配列が入ってきた場合、trueを返却する", t => {
   t.is(validate.isUuids(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), true);
 });
 test("isUuids関数に日付の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isUuids([new Date(),new Date()]), false);
 });
 test("isUuids関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
  t.is(validate.isUuids([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
 });

 test("====================isUuids End====================\n", t => {
  t.is(false, false);
 });

/**
* isBlank
*/
test("====================isBlank Start====================", t => {
 t.is(true, true);
});
test("isBlank関数にNULLが入ってきた場合、trueを返却する", t => {
t.is(validate.isBlank(null), true);
});
test("isBlank関数に未定義値が入ってきた場合、trueを返却する", t => {
t.is(validate.isBlank(undefined), true);
});
test("isBlank関数に空文字が入ってきた場合、trueを返却する", t => {
t.is(validate.isBlank(""), true);
});
test("isBlank関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("文字列"), false);
});
test("isBlank関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-01-01 00:00:00"), false);
});
test("isBlank関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-12-31 12:59:59"), false);
});
test("isBlank関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-00-01 00:00:00"), false);
});
test("isBlank関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-13-01 00:00:00"), false);
});
test("isBlank関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-01-32 00:00:00"), false);
});
test("isBlank関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-01-01 25:00:00"), false);
});
test("isBlank関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-01-01 00:60:00"), false);
});
test("isBlank関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-01-01 00:00:60"), false);
});
test("isBlank関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("2018-13-32 25:60:60"), false);
});
test("isBlank関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank("AAAA-01-01 00:00:00"), false);
});
test("isBlank関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(true), false);
});
test("isBlank関数に真偽値（FALSE）が入ってきた場合、trueを返却する", t => {
t.is(validate.isBlank(false), true);
});
test("isBlank関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(0), false);
});
test("isBlank関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(1), false);
});
test("isBlank関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(-1), false);
});
test("isBlank関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(1.11), false);
});
test("isBlank関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(-1.11), false);
});
test("isBlank関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.MAX_VALUE), false);
});
test("isBlank関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.MAX_VALUE + 1), false);
});
test("isBlank関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.MIN_VALUE), false);
});
test("isBlank関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.MIN_VALUE - 1), false);
});
test("isBlank関数に数字の無限が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.POSITIVE_INFINITY), false);
});
test("isBlank関数に数字の無限+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.POSITIVE_INFINITY + 1), false);
});
test("isBlank関数に数字の-無限が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.NEGATIVE_INFINITY), false);
});
test("isBlank関数に数字の-無限-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank(Number.NEGATIVE_INFINITY - 1), false);
});
test("isBlank関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isBlank([]), false);
});
test("isBlank関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isBlank(["配列","配列"]), false);
});
test("isBlank関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isBlank({}), false);
});
test("isBlank関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isBlank({"key":"オブジェクト"}), false);
});
test("isBlank関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isBlank(testUnitFunc), false);
});
test("isBlank関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isBlank("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isBlank End====================\n", t => {
 t.is(true, true);
});


/**
  * isBlanks
  */
test("====================isBlanks Start====================", t => {
 t.is(true, true);
});
test("isBlanks関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks(null), false);
});
test("isBlanks関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks(undefined), false);
});
test("isBlanks関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks("文字列"), false);
});
test("isBlanks関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks({"key":"オブジェクト"}), false);
});
test("isBlanks関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks(false), false);
});
test("isBlanks関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks(0), false);
});
test("isBlanks関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBlanks([]), true);
});
test("isBlanks関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isBlanks(testUnitFunc), false);
});
test("isBlanks関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isBlanks(new Date()), false);
});


test("isBlanks関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([-1.1,-1,1,0,1,1.1]),  false);
});
test("isBlanks関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([-2,-1,0,1,2]), false);
});
test("isBlanks関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([-3,-2,-1]), false);
});
test("isBlanks関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([-3,-2,-1,0]), false);
});
test("isBlanks関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([1,2,3]), false);
});
test("isBlanks関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([0,1,2,3]), false);
});
test("isBlanks関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([true, false]), false);
});
test("isBlanks関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([true, true]), false);
});
test("isBlanks関数にfalseの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBlanks([false, false]), true);
});
test("isBlanks関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([function(){}, function(){}]), false);
});
test("isBlanks関数にundefinedの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBlanks([undefined, undefined]), true);
});
test("isBlanks関数にnullの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBlanks([null, null]), true);
});
test("isBlanks関数にblankの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isBlanks([undefined, null, "", false]), true);
});
test("isBlanks関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks(["文字列","mojiretsu"]), false);
});
test("isBlanks関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([["配列","配列"],["配列","配列"]]), false);
});
test("isBlanks関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([{"key":"value"},{"key2":"値"}]), false);
});
test("isBlanks関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isBlanks(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isBlanks関数に日付の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isBlanks([new Date(),new Date()]), false);
});
test("isBlanks関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isBlanks([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isBlanks End====================\n", t => {
 t.is(false, false);
});

/**
* isDateTimeString
*/

test("====================isDateTimeString Start====================", t => {
 t.is(true, true);
});
test("isDateTimeString関数にNULLが入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(null), false);
});
test("isDateTimeString関数に未定義値が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(undefined), false);
});
test("isDateTimeString関数に空文字が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(""), false);
});
test("isDateTimeString関数に文字列が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("文字列"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、trueを返却する", t => {
t.is(validate.isDateTimeString("2018-01-01 00:00:00"), true);
});
test("isDateTimeString関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、trueを返却する", t => {
t.is(validate.isDateTimeString("2018-12-31 12:59:59"), true);
});
test("isDateTimeString関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-00-01 00:00:00"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-13-01 00:00:00"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-01-32 00:00:00"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-01-01 25:00:00"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-01-01 00:60:00"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-01-01 00:00:60"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("2018-13-32 25:60:60"), false);
});
test("isDateTimeString関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString("AAAA-01-01 00:00:00"), false);
});
test("isDateTimeString関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(true), false);
});
test("isDateTimeString関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(false), false);
});
test("isDateTimeString関数に数字の0が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(0), false);
});
test("isDateTimeString関数に数字の1が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(1), false);
});
test("isDateTimeString関数に数字の-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(-1), false);
});
test("isDateTimeString関数に数字の1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(1.11), false);
});
test("isDateTimeString関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(-1.11), false);
});
test("isDateTimeString関数に数字の最大値が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.MAX_VALUE), false);
});
test("isDateTimeString関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.MAX_VALUE + 1), false);
});
test("isDateTimeString関数に数字の最小値が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.MIN_VALUE), false);
});
test("isDateTimeString関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.MIN_VALUE - 1), false);
});
test("isDateTimeString関数に数字の無限が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.POSITIVE_INFINITY), false);
});
test("isDateTimeString関数に数字の無限+1が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.POSITIVE_INFINITY + 1), false);
});
test("isDateTimeString関数に数字の-無限が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.NEGATIVE_INFINITY), false);
});
test("isDateTimeString関数に数字の-無限-1が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString(Number.NEGATIVE_INFINITY - 1), false);
});
test("isDateTimeString関数に空の配列が入ってきた場合、falseを返却する", t => {
t.is(validate.isDateTimeString([]), false);
});
test("isDateTimeString関数に配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isDateTimeString(["配列","配列"]), false);
});
test("isDateTimeString関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isDateTimeString({}), false);
});
test("isDateTimeString関数にオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isDateTimeString({"key":"オブジェクト"}), false);
});
test("isDateTimeString関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isDateTimeString(testUnitFunc), false);
});
test("isDateTimeString関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isDateTimeString("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("====================isDateTimeString End====================\n", t => {
 t.is(true, true);
});


/**
  * isDate
  */
test("====================isDate Start====================", t => {
 t.is(true, true);
});
test("isDate関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(null), false);
});
test("isDate関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(undefined), false);
});
test("isDate関数に空文字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(""), false);
});
test("isDate関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("文字列"), false);
});
test("isDate関数にタイムスタンプ文字列（正常年月最小）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-01-01 00:00:00"), false);
});
test("isDate関数にタイムスタンプ文字列（正常年月最大）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-12-31 12:59:59"), false);
});
test("isDate関数にタイムスタンプ文字列（月が値外1より下）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-00-01 00:00:00"), false);
});
test("isDate関数にタイムスタンプ文字列（月が値外12より上）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-13-01 00:00:00"), false);
});
test("isDate関数にタイムスタンプ文字列（日が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-01-32 00:00:00"), false);
});
test("isDate関数にタイムスタンプ文字列（時が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-01-01 25:00:00"), false);
});
test("isDate関数にタイムスタンプ文字列（分が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-01-01 00:60:00"), false);
});
test("isDate関数にタイムスタンプ文字列（秒が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-01-01 00:00:60"), false);
});
test("isDate関数にタイムスタンプ文字列（全部が値外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("2018-13-32 25:60:60"), false);
});
test("isDate関数にタイムスタンプ文字列（正規表現対象外）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate("AAAA-01-01 00:00:00"), false);
});
test("isDate関数に真偽値（TRUE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(false), false);
});
test("isDate関数に真偽値（FALSE）が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(false), false);
});
test("isDate関数に数字の0が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(0), false);
});
test("isDate関数に数字の1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(1), false);
});
test("isDate関数に数字の-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(-1), false);
});
test("isDate関数に数字の1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(1.11), false);
});
test("isDate関数に数字の-1.11が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(-1.11), false);
});
test("isDate関数に整数の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.MAX_VALUE), false);
});
test("isDate関数に整数の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.MAX_VALUE + 1), false);
});
test("isDate関数に正の値の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.MIN_VALUE), false);
});
test("isDate関数に整数の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.MIN_VALUE - 1), false);
});
test("isDate関数に数字の最大値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.POSITIVE_INFINITY), false);
});
test("isDate関数に数字の最大値+1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.POSITIVE_INFINITY + 1), false);
});
test("isDate関数に数字の最小値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.NEGATIVE_INFINITY), false);
});
test("isDate関数に数字の最小値-1が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(Number.NEGATIVE_INFINITY - 1), false);
});
test("isDate関数に空の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate([]), false);
});
test("isDate関数に配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate(["配列","配列"]), false);
});
test("isDate関数に空のオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate({}), false);
});
test("isDate関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isDate({"key":"オブジェクト"}), false);
});
test("isDate関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isDate(testUnitFunc), false);
});
test("isDate関数にUUID文字列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isDate("012345aB-0aAB-0aAB-0aAB-012345abcABC"), false);
});
test("isDate関数にDateオブジェクトが入ってきた場合、trueを返却する", t => {
  t.is(validate.isDate(new Date()), true);
});

test("====================isDate End====================\n", t => {
 t.is(false, false);
});


/**
  * isDates
  */
test("====================isDates Start====================", t => {
 t.is(true, true);
});
test("isDates関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates(null), false);
});
test("isDates関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates(undefined), false);
});
test("isDates関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates("文字列"), false);
});
test("isDates関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates({"key":"オブジェクト"}), false);
});
test("isDates関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates(false), false);
});
test("isDates関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates(0), false);
});
test("isDates関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isDates([]), true);
});
test("isDates関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isDates(testUnitFunc), false);
});
test("isDates関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isDates(new Date()), false);
});


test("isDates関数に-1.1〜1.1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([-1.1,-1,1,0,1,1.1]),  false);
});
test("isDates関数に-2〜2までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([-2,-1,0,1,2]), false);
});
test("isDates関数に-3〜-1までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([-3,-2,-1]), false);
});
test("isDates関数に-3〜0までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([-3,-2,-1,0]), false);
});
test("isDates関数に1〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([1,2,3]), false);
});
test("isDates関数に0〜3までの数字の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([0,1,2,3]), false);
});
test("isDates関数にtrue,falseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([true, false]), false);
});
test("isDates関数にtrueの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([true, true]), false);
});
test("isDates関数にfalseの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([false, false]), false);
});
test("isDates関数にfunctionの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([function(){}, function(){}]), false);
});
test("isDates関数にundefinedの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([undefined, undefined]), false);
});
test("isDates関数にnullの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([null, null]), false);
});
test("isDates関数にblankの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([undefined, null, "", false]), false);
});
test("isDates関数に文字列の配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates(["文字列","mojiretsu"]), false);
});
test("isDates関数に二次元配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([["配列","配列"],["配列","配列"]]), false);
});
test("isDates関数にオブジェクトの配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isDates([{"key":"value"},{"key2":"値"}]), false);
});
test("isDates関数にUUID文字列の配列が入ってきた場合、falseを返却する", t => {
  t.is(validate.isDates(["012345aB-0aAB-0aAB-0aAB-012345abcABC","012345aB-0aAB-0aAB-0aAB-012345abcABC"]), false);
});
test("isDates関数に文字列の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isDates([new Date(),new Date()]), true);
});
test("isDates関数に様々な型が入った配列が入ってきた場合、　falseを返却する", t => {
 t.is(validate.isDates([0,"文字列",["配列","配列"],{"key":"value"},new Date]), false);
});

test("====================isDates End====================\n", t => {
 t.is(false, false);
});


/**
  * isIncluded
  */
test("====================isIncluded Start====================", t => {
 t.is(true, true);
});
test("isIncluded関数にNULLが入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded(null, null), false);
});
test("isIncluded関数に未定義値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded(undefined, undefined), false);
});
test("isIncluded関数に文字列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded("文字列", "文字列"), false);
});
test("isIncluded関数にオブジェクトが入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded({"key":"オブジェクト"}, {"key":"オブジェクト"}), false);
});
test("isIncluded関数に真偽値が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded(false, false), false);
});
test("isIncluded関数に数字が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded(0, 0), false);
});
test("isIncluded関数に空の配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded([], []), true);
});
test("isIncluded関数に関数が入ってきた場合、falseを返却する", t => {
  const testUnitFunc = function(){
    console.log("test");
  };
  t.is(validate.isIncluded(testUnitFunc, testUnitFunc), false);
});
test("isIncluded関数にDateオブジェクトが入ってきた場合、falseを返却する", t => {
  t.is(validate.isIncluded(new Date(), new Date()), false);
});
test("isIncluded関数に同じ文字列配列が入ってきた場合、　trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", "bbb"], ["aaa", "bbb"]), true);
});
test("isIncluded関数の確認用配列に全要素側配列内の要素のみで構成された文字列配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", "bbb", "ccc"], ["aaa", "bbb"]), true);
});
test("isIncluded関数の確認用配列に全要素側配列外の要素を含んだ文字列配列が入ってきた場合、falseを返却する", t => {
 t.is(validate.isIncluded(["aaa", "bbb"], ["aaa", "bbb", "ccc"]), false);
});
test("isIncluded関数の全要素配列に含まれる文字列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", "bbb"], "aaa"), true);
});
test("isIncluded関数の全要素配列にnullが含まれる場合にnullのみの配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", null], [null, null]), true);
});
test("isIncluded関数の全要素配列にnullが含まれる場合にnullが入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", null], null), true);
});
test("isIncluded関数の全要素配列に複数の型を含んだ場合に内包する配列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", 111], [111, 111, "aaa"]), true);
});
test("isIncluded関数の全要素配列に複数の型を含んだ場合に内包する文字列が入ってきた場合、trueを返却する", t => {
 t.is(validate.isIncluded(["aaa", 1111], 1111), true);
});


test("====================isIncluded End====================\n", t => {
 t.is(false, false);
});
